@@ -602,5 +602,54 @@ replace(/(?:^|:|,)(?:\s*\[)+/g, ''))) {
     }
 })();
 
+Seed.repl = function()
+{
+	try
+	{
+		if(readline)
+		{
+			// readline is loaded
+		}
+	}
+	catch (e)
+	{
+		try
+		{
+			Seed.import_namespace("readline");
+		}
+		catch (e)
+		{
+			Seed.print(e.name + " " + e.message);
+			return true;
+		}
+	}
+	
+	try
+	{
+		item = readline.readline("> ");
+		if (item == "continue")
+			return false;
+		Seed.print(eval(item));
+	}
+	catch (e)
+	{
+		Seed.print(e.name + " " + e.message);
+	}
+	return true;
+}
+
+
+Seed.glib_repl = function()
+{
+	GLib.idle_add(Seed.repl, null);
+}
+
+Seed.thread_repl = function()
+{
+	GLib.thread_create_full(function() { while(Seed.repl()){} }, 
+							null, 0, true);
+	
+}
+
 Seed.printf = function () { Seed.print(Seed.sprintf.apply(this, arguments)) };
 
